#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
/****************************************************************************
** Meta object code from reading C++ file 'main-window.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/cygdrive/e/cyg_pub/devel/octave/octave-4.0.1-1.x86_64/src/octave-4.0.1/libgui/src/main-window.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'main-window.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_main_window[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      91,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      15,       // signalCount

 // signals: signature, parameters, type, tag, flags
      15,   13,   12,   12, 0x05,
      76,   12,   12,   12, 0x05,
     103,   12,   12,   12, 0x05,
     138,   12,   12,   12, 0x05,
     166,   12,   12,   12, 0x05,
     191,   12,   12,   12, 0x05,
     217,   12,   12,   12, 0x05,
     252,  242,   12,   12, 0x05,
     296,  242,   12,   12, 0x05,
     357,  340,   12,   12, 0x05,
     407,   12,   12,   12, 0x05,
     430,   12,   12,   12, 0x05,
     454,   12,   12,   12, 0x05,
     473,   12,   12,   12, 0x05,
     499,  487,   12,   12, 0x05,

 // slots: signature, parameters, type, tag, flags
     547,  535,   12,   12, 0x0a,
     580,   12,   12,   12, 0x0a,
     620,  606,   12,   12, 0x0a,
     651,   12,   12,   12, 0x0a,
     688,  683,   12,   12, 0x0a,
     727,   12,   12,   12, 0x2a,
     759,   12,   12,   12, 0x0a,
     797,   12,   12,   12, 0x0a,
     830,   12,   12,   12, 0x0a,
     879,  861,   12,   12, 0x0a,
     927,   12,   12,   12, 0x0a,
     958,  949,   12,   12, 0x0a,
     976,   12,   12,   12, 0x2a,
     997,  987,   12,   12, 0x0a,
    1016,   12,   12,   12, 0x2a,
    1028,   12,   12,   12, 0x0a,
    1061,   12,   12,   12, 0x0a,
    1092, 1085,   12,   12, 0x0a,
    1129,   12,   12,   12, 0x2a,
    1168, 1163,   12,   12, 0x0a,
    1200,   12,   12,   12, 0x0a,
    1224,   12,   12,   12, 0x0a,
    1252,   12,   12,   12, 0x0a,
    1270,   12,   12,   12, 0x0a,
    1293,   12,   12,   12, 0x0a,
    1327, 1315,   12,   12, 0x0a,
    1368,   12,   12,   12, 0x2a,
    1419, 1402,   12,   12, 0x0a,
    1457,   12,   12,   12, 0x0a,
    1486, 1477,   12,   12, 0x0a,
    1520,   12,   12,   12, 0x0a,
    1546,   12,   12,   12, 0x0a,
    1571, 1564,   12,   12, 0x0a,
    1585,   12,   12,   12, 0x0a,
    1605, 1601,   12,   12, 0x0a,
    1631,   12,   12,   12, 0x0a,
    1654, 1601,   12,   12, 0x0a,
    1693,   12,   12,   12, 0x0a,
    1715,   12,   12,   12, 0x0a,
    1744, 1601,   12,   12, 0x0a,
    1786, 1781,   12,   12, 0x0a,
    1818,   12,   12,   12, 0x0a,
    1846,   12,   12,   12, 0x0a,
    1870,   12,   12,   12, 0x0a,
    1893,   12,   12,   12, 0x0a,
    1910,   12,   12,   12, 0x0a,
    1928,   12,   12,   12, 0x0a,
    1946,   12,   12,   12, 0x0a,
    1963,   12,   12,   12, 0x0a,
    1976,  242,   12,   12, 0x0a,
    2028,  242,   12,   12, 0x0a,
    2080,  340,   12,   12, 0x0a,
    2138,   12,   12,   12, 0x0a,
    2154,   12,   12,   12, 0x0a,
    2175, 1477,   12,   12, 0x0a,
    2205,   12,   12,   12, 0x0a,
    2222,   12,   12,   12, 0x0a,
    2251,   12,   12,   12, 0x0a,
    2267,   12,   12,   12, 0x0a,
    2284,   12,   12,   12, 0x0a,
    2296,   12,   12,   12, 0x0a,
    2362, 2321,   12,   12, 0x0a,
    2507, 2440,   12,   12, 0x0a,
    2609, 2604,   12,   12, 0x0a,
    2731, 2690,   12,   12, 0x0a,
    2801,  683,   12,   12, 0x0a,
    2826,   12,   12,   12, 0x0a,
    2857, 2848,   12,   12, 0x0a,
    2877,   12,   12,   12, 0x2a,
    2890,   12,   12,   12, 0x0a,
    2922, 2915,   12,   12, 0x0a,
    2949, 2915,   12,   12, 0x0a,
    2987, 2981,   12,   12, 0x0a,
    3012,   12,   12,   12, 0x0a,
    3052,   12,   12,   12, 0x0a,
    3097,   12, 3070,   12, 0x0a,

       0        // eod
};

static const char qt_meta_stringdata_main_window[] = {
    "main_window\0\0,\0"
    "active_dock_changed(octave_dock_widget*,octave_dock_widget*)\0"
    "editor_focus_changed(bool)\0"
    "settings_changed(const QSettings*)\0"
    "init_terminal_size_signal()\0"
    "new_file_signal(QString)\0"
    "open_file_signal(QString)\0"
    "show_doc_signal(QString)\0file,line\0"
    "insert_debugger_pointer_signal(QString,int)\0"
    "delete_debugger_pointer_signal(QString,int)\0"
    "insert,file,line\0"
    "update_breakpoint_marker_signal(bool,QString,int)\0"
    "copyClipboard_signal()\0pasteClipboard_signal()\0"
    "selectAll_signal()\0undo_signal()\0"
    "action_list\0add_actions_signal(QList<QAction*>)\0"
    "w_old,w_new\0focus_changed(QWidget*,QWidget*)\0"
    "request_reload_settings()\0statusMessage\0"
    "report_status_message(QString)\0"
    "handle_save_workspace_request()\0file\0"
    "handle_load_workspace_request(QString)\0"
    "handle_load_workspace_request()\0"
    "handle_clear_command_window_request()\0"
    "handle_clear_workspace_request()\0"
    "handle_clear_history_request()\0"
    "old_name,new_name\0"
    "handle_rename_variable_request(QString,QString)\0"
    "handle_undo_request()\0commands\0"
    "new_file(QString)\0new_file()\0file_name\0"
    "open_file(QString)\0open_file()\0"
    "open_online_documentation_page()\0"
    "display_release_notes()\0serial\0"
    "load_and_display_community_news(int)\0"
    "load_and_display_community_news()\0"
    "news\0display_community_news(QString)\0"
    "open_bug_tracker_page()\0"
    "open_octave_packages_page()\0"
    "open_agora_page()\0open_contribute_page()\0"
    "open_developer_page()\0desired_tab\0"
    "process_settings_dialog_request(QString)\0"
    "process_settings_dialog_request()\0"
    "file,remove_file\0copy_image_to_clipboard(QString,bool)\0"
    "show_about_octave()\0settings\0"
    "notice_settings(const QSettings*)\0"
    "confirm_shutdown_octave()\0prepare_to_exit()\0"
    "status\0exit_app(int)\0reset_windows()\0"
    "dir\0change_directory(QString)\0"
    "browse_for_directory()\0"
    "set_current_working_directory(QString)\0"
    "change_directory_up()\0"
    "accept_directory_line_edit()\0"
    "execute_command_in_terminal(QString)\0"
    "info\0run_file_in_terminal(QFileInfo)\0"
    "handle_new_figure_request()\0"
    "handle_enter_debugger()\0handle_exit_debugger()\0"
    "debug_continue()\0debug_step_into()\0"
    "debug_step_over()\0debug_step_out()\0"
    "debug_quit()\0"
    "handle_insert_debugger_pointer_request(QString,int)\0"
    "handle_delete_debugger_pointer_request(QString,int)\0"
    "handle_update_breakpoint_marker_request(bool,QString,int)\0"
    "read_settings()\0init_terminal_size()\0"
    "set_window_layout(QSettings*)\0"
    "write_settings()\0connect_visibility_changed()\0"
    "copyClipboard()\0pasteClipboard()\0"
    "selectAll()\0connect_uiwidget_links()\0"
    "message,title,icon,button,defbutton,role\0"
    "handle_create_dialog(QString,QString,QString,QStringList,QString,QStri"
    "ngList)\0"
    "list,mode,width,height,initial,name,prompt,ok_string,cancel_string\0"
    "handle_create_listview(QStringList,QString,int,int,QIntList,QString,QS"
    "tringList,QString,QString)\0"
    ",,,,\0"
    "handle_create_inputlayout(QStringList,QString,QFloatList,QFloatList,QS"
    "tringList)\0"
    "filters,title,filename,dirname,multimode\0"
    "handle_create_filedialog(QStringList,QString,QString,QString,QString)\0"
    "handle_show_doc(QString)\0handle_octave_ready()\0"
    "startdir\0find_files(QString)\0find_files()\0"
    "find_files_finished(int)\0enable\0"
    "set_global_shortcuts(bool)\0"
    "set_global_edit_shortcuts(bool)\0ht,wd\0"
    "set_screen_size(int,int)\0"
    "clipboard_has_changed(QClipboard::Mode)\0"
    "clear_clipboard()\0QList<octave_dock_widget*>\0"
    "get_dock_widget_list()\0"
};

void main_window::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        main_window *_t = static_cast<main_window *>(_o);
        switch (_id) {
        case 0: _t->active_dock_changed((*reinterpret_cast< octave_dock_widget*(*)>(_a[1])),(*reinterpret_cast< octave_dock_widget*(*)>(_a[2]))); break;
        case 1: _t->editor_focus_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->settings_changed((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
        case 3: _t->init_terminal_size_signal(); break;
        case 4: _t->new_file_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->open_file_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->show_doc_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->insert_debugger_pointer_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->delete_debugger_pointer_signal((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 9: _t->update_breakpoint_marker_signal((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 10: _t->copyClipboard_signal(); break;
        case 11: _t->pasteClipboard_signal(); break;
        case 12: _t->selectAll_signal(); break;
        case 13: _t->undo_signal(); break;
        case 14: _t->add_actions_signal((*reinterpret_cast< QList<QAction*>(*)>(_a[1]))); break;
        case 15: _t->focus_changed((*reinterpret_cast< QWidget*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 16: _t->request_reload_settings(); break;
        case 17: _t->report_status_message((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 18: _t->handle_save_workspace_request(); break;
        case 19: _t->handle_load_workspace_request((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->handle_load_workspace_request(); break;
        case 21: _t->handle_clear_command_window_request(); break;
        case 22: _t->handle_clear_workspace_request(); break;
        case 23: _t->handle_clear_history_request(); break;
        case 24: _t->handle_rename_variable_request((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 25: _t->handle_undo_request(); break;
        case 26: _t->new_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->new_file(); break;
        case 28: _t->open_file((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 29: _t->open_file(); break;
        case 30: _t->open_online_documentation_page(); break;
        case 31: _t->display_release_notes(); break;
        case 32: _t->load_and_display_community_news((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->load_and_display_community_news(); break;
        case 34: _t->display_community_news((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 35: _t->open_bug_tracker_page(); break;
        case 36: _t->open_octave_packages_page(); break;
        case 37: _t->open_agora_page(); break;
        case 38: _t->open_contribute_page(); break;
        case 39: _t->open_developer_page(); break;
        case 40: _t->process_settings_dialog_request((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 41: _t->process_settings_dialog_request(); break;
        case 42: _t->copy_image_to_clipboard((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 43: _t->show_about_octave(); break;
        case 44: _t->notice_settings((*reinterpret_cast< const QSettings*(*)>(_a[1]))); break;
        case 45: _t->confirm_shutdown_octave(); break;
        case 46: _t->prepare_to_exit(); break;
        case 47: _t->exit_app((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 48: _t->reset_windows(); break;
        case 49: _t->change_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 50: _t->browse_for_directory(); break;
        case 51: _t->set_current_working_directory((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 52: _t->change_directory_up(); break;
        case 53: _t->accept_directory_line_edit(); break;
        case 54: _t->execute_command_in_terminal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 55: _t->run_file_in_terminal((*reinterpret_cast< const QFileInfo(*)>(_a[1]))); break;
        case 56: _t->handle_new_figure_request(); break;
        case 57: _t->handle_enter_debugger(); break;
        case 58: _t->handle_exit_debugger(); break;
        case 59: _t->debug_continue(); break;
        case 60: _t->debug_step_into(); break;
        case 61: _t->debug_step_over(); break;
        case 62: _t->debug_step_out(); break;
        case 63: _t->debug_quit(); break;
        case 64: _t->handle_insert_debugger_pointer_request((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 65: _t->handle_delete_debugger_pointer_request((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 66: _t->handle_update_breakpoint_marker_request((*reinterpret_cast< bool(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 67: _t->read_settings(); break;
        case 68: _t->init_terminal_size(); break;
        case 69: _t->set_window_layout((*reinterpret_cast< QSettings*(*)>(_a[1]))); break;
        case 70: _t->write_settings(); break;
        case 71: _t->connect_visibility_changed(); break;
        case 72: _t->copyClipboard(); break;
        case 73: _t->pasteClipboard(); break;
        case 74: _t->selectAll(); break;
        case 75: _t->connect_uiwidget_links(); break;
        case 76: _t->handle_create_dialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QStringList(*)>(_a[6]))); break;
        case 77: _t->handle_create_listview((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QIntList(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QStringList(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8])),(*reinterpret_cast< const QString(*)>(_a[9]))); break;
        case 78: _t->handle_create_inputlayout((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QFloatList(*)>(_a[3])),(*reinterpret_cast< const QFloatList(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5]))); break;
        case 79: _t->handle_create_filedialog((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 80: _t->handle_show_doc((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 81: _t->handle_octave_ready(); break;
        case 82: _t->find_files((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 83: _t->find_files(); break;
        case 84: _t->find_files_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 85: _t->set_global_shortcuts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 86: _t->set_global_edit_shortcuts((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 87: _t->set_screen_size((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 88: _t->clipboard_has_changed((*reinterpret_cast< QClipboard::Mode(*)>(_a[1]))); break;
        case 89: _t->clear_clipboard(); break;
        case 90: { QList<octave_dock_widget*> _r = _t->get_dock_widget_list();
            if (_a[0]) *reinterpret_cast< QList<octave_dock_widget*>*>(_a[0]) = _r; }  break;
        default: ;
        }
    }
}

const QMetaObjectExtraData main_window::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject main_window::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_main_window,
      qt_meta_data_main_window, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &main_window::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *main_window::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *main_window::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_main_window))
        return static_cast<void*>(const_cast< main_window*>(this));
    return QMainWindow::qt_metacast(_clname);
}

int main_window::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 91)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 91;
    }
    return _id;
}

// SIGNAL 0
void main_window::active_dock_changed(octave_dock_widget * _t1, octave_dock_widget * _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void main_window::editor_focus_changed(bool _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void main_window::settings_changed(const QSettings * _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void main_window::init_terminal_size_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 3, 0);
}

// SIGNAL 4
void main_window::new_file_signal(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void main_window::open_file_signal(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void main_window::show_doc_signal(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void main_window::insert_debugger_pointer_signal(const QString & _t1, int _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void main_window::delete_debugger_pointer_signal(const QString & _t1, int _t2)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void main_window::update_breakpoint_marker_signal(bool _t1, const QString & _t2, int _t3)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void main_window::copyClipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 10, 0);
}

// SIGNAL 11
void main_window::pasteClipboard_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 11, 0);
}

// SIGNAL 12
void main_window::selectAll_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 12, 0);
}

// SIGNAL 13
void main_window::undo_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 13, 0);
}

// SIGNAL 14
void main_window::add_actions_signal(QList<QAction*> _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}
static const uint qt_meta_data_news_reader[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: signature, parameters, type, tag, flags
      18,   13,   12,   12, 0x05,
      47,   12,   12,   12, 0x05,

 // slots: signature, parameters, type, tag, flags
      58,   12,   12,   12, 0x0a,

       0        // eod
};

static const char qt_meta_stringdata_news_reader[] = {
    "news_reader\0\0news\0display_news_signal(QString)\0"
    "finished()\0process()\0"
};

void news_reader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        news_reader *_t = static_cast<news_reader *>(_o);
        switch (_id) {
        case 0: _t->display_news_signal((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->finished(); break;
        case 2: _t->process(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData news_reader::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject news_reader::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_news_reader,
      qt_meta_data_news_reader, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &news_reader::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *news_reader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *news_reader::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_news_reader))
        return static_cast<void*>(const_cast< news_reader*>(this));
    return QObject::qt_metacast(_clname);
}

int news_reader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void news_reader::display_news_signal(const QString & _t1)
{
    void *_a[] = { 0, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void news_reader::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, 0);
}
QT_END_MOC_NAMESPACE
